;;
;; mailman.scm
;;
;; Mailman management interface - public API
;;
;; ISC License
;;
;; Copyright 2023 Brmlab, z.s.
;; Dominik Pantůček <dominik.pantucek@trustica.cz>
;;
;; Permission to use, copy, modify, and/or distribute this software
;; for any purpose with or without fee is hereby granted, provided
;; that the above copyright notice and this permission notice appear
;; in all copies.
;; 
;; THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL
;; WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED
;; WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE
;; AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR
;; CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS
;; OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
;; NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
;; CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
;;

(declare (unit mailman))

(module
 mailman
 (
  mailman-list-name
  mailman-list-members

  find-mailman-list
  
  email-in-mailman-list?
  )

 (import scheme
	 (chicken base)
	 (chicken module)
	 mailman2
	 mailman-common)

 (define *mailman-version* (make-parameter 2))

 (define-syntax define-mailman-proc
   (syntax-rules ()
     ((_ name proc2)
      (begin
	(export name)
	(define (name . args)
	  (case (*mailman-version*)
	    ((2) (apply proc2 args))))))
     ((_ name proc2 proc3)
      (begin
	(export name)
	(define (name . args)
	  (case (*mailman-version*)
	    ((2) (apply proc2 args))
	    ((3) (apply proc3 args))))))))

 (define-mailman-proc list-mailman-lists list-mailman2-lists)
 (define-mailman-proc list-mailman-list-members list-mailman2-list-members)
 (define-mailman-proc load-mailman-list load-mailman2-list)
 (define-mailman-proc load-mailman-lists load-mailman2-lists)

 ;; List of lists, returns the whole list record (including name)
 (define (find-mailman-list lsts name)
   (assoc name lsts))

 )
